Token

Enum Token 

pub enum Token {
    Push(Value),
    PushVar(Var),
    Write(Out),
    Binop(Binop),
    Unop(Unop),
    Function(Function),
    Noop,
}
RPN Token

Variants



Push(Value)

Push a value onto the stack



PushVar(Var)

Push variable value onto the stack



Write(Out)

Write top of stack to in-out variable



Binop(Binop)

Binary operation

Pops 2 values from the stack, performs the operation, and pushes the result back onto the stack



Unop(Unop)

Unary operation

Replaces the top value on the stack with the result of the operation



Function(Function)

Function call

Pops a number of arguments from the stack, evaluates the function, and pushes the result back onto the stack.



Noop

No operation