math_jit::rpn

Struct Program

pub struct Program(pub Vec<Token>);
Parsed program representation

The program is represented using Reverse Polish Notation, which is lends to easy iterative translation into CLIF as well as to simple optimizations.

Tuple Fields

0: Vec<Token>

Implementations

Source

impl Program

pub fn new(tokens: Vec<Token>) -> Self

Constructs program directly from RPN

pub fn parse_from_infix(expr: &str) -> Result<Self, JitError>

Parses an infix notation into RPN

pub fn propagate_constants(&mut self)

Evaluate constant expressions

Optimizes binary and unary operations:

  • replace [const0, const1, op] with [op(const0, const1)]
  • replace [const, op] with [op(const)]

This operation is repeated until no progress can be made. Token::Noop is removed in the process.

Doesn’t support reordering of associative operations, so [var, const0, add, const1, add] is not replaced with [var, add(const0, const1), add] and so on.